@@ -1,23 +1,20 @@
-"use strict";
+'use strict';
 
 // we run mocha manually otherwise istanbul coverage won't work
 // run `npm test --coverage` to generate coverage report
 
 var Mocha = require('mocha');
 
-
 // ---
 
-
-
 // to set these options run the test script like:
 //  > BAIL=true GREP=array_expression REPORTER=dot npm test
 var opts = {
   ui: 'bdd',
-  bail: !!(process.env.BAIL),
-  reporter:( process.env.REPORTER || 'spec'),
+  bail: !!process.env.BAIL,
+  reporter: process.env.REPORTER || 'spec',
   grep: process.env.GREP,
-  colors: true
+  colors: true,
 };
 
 // we use the dot reporter on travis since it works better
@@ -32,13 +29,12 @@ if (process.env.INVERT) {
 }
 
 var expand = require('glob-expand');
-expand('test/specs/**/*.js').forEach(function (file){
+expand('test/specs/**/*.js').forEach(function (file) {
   m.addFile(file);
 });
 
-m.run(function(err) {
+m.run(function (err) {
   var exitCode = err ? 1 : 0;
   if (err) console.log('failed tests: ' + err);
   process.exit(exitCode);
 });
-
